AUDIT: r17341 - gnucash/trunk/src/report/standard-reports - Reports: Make "Average Cost" the default price source for several additional standard reports.

Charles Day cedayiv at cvs.gnucash.org
Wed Jul 16 11:55:50 EDT 2008


Author: cedayiv
Date: 2008-07-16 11:55:50 -0400 (Wed, 16 Jul 2008)
New Revision: 17341
Trac: http://svn.gnucash.org/trac/changeset/17341

Modified:
   gnucash/trunk/src/report/standard-reports/account-piecharts.scm
   gnucash/trunk/src/report/standard-reports/account-summary.scm
   gnucash/trunk/src/report/standard-reports/balance-sheet.scm
   gnucash/trunk/src/report/standard-reports/budget.scm
   gnucash/trunk/src/report/standard-reports/equity-statement.scm
   gnucash/trunk/src/report/standard-reports/income-statement.scm
Log:
Reports: Make "Average Cost" the default price source for several additional standard reports.
BP


Modified: gnucash/trunk/src/report/standard-reports/account-piecharts.scm
===================================================================
--- gnucash/trunk/src/report/standard-reports/account-summary.scm	2008-07-16 15:39:17 UTC (rev 17340)
+++ gnucash/trunk/src/report/standard-reports/account-summary.scm	2008-07-16 15:55:50 UTC (rev 17341)
@@ -188,7 +188,7 @@
     
     (gnc:options-add-price-source! 
      options pagename-commodities
-     optname-price-source "b" 'weighted-average)
+     optname-price-source "b" 'average-cost)
     
     (add-option 
      (gnc:make-simple-boolean-option

Modified: gnucash/trunk/src/report/standard-reports/balance-sheet.scm
===================================================================
--- gnucash/trunk/src/report/standard-reports/balance-sheet.scm	2008-07-16 15:39:17 UTC (rev 17340)
+++ gnucash/trunk/src/report/standard-reports/balance-sheet.scm	2008-07-16 15:55:50 UTC (rev 17341)
@@ -207,7 +207,7 @@
     
     (gnc:options-add-price-source! 
      options pagename-commodities
-     optname-price-source "b" 'weighted-average)
+     optname-price-source "b" 'average-cost)
     
     (add-option 
      (gnc:make-simple-boolean-option

Modified: gnucash/trunk/src/report/standard-reports/budget.scm
===================================================================
--- gnucash/trunk/src/report/standard-reports/budget.scm	2008-07-16 15:39:17 UTC (rev 17340)
+++ gnucash/trunk/src/report/standard-reports/budget.scm	2008-07-16 15:55:50 UTC (rev 17341)
@@ -68,7 +68,7 @@
     ;; optname-from-date optname-to-date "a")
 
     (gnc:options-add-price-source!
-     options gnc:pagename-general optname-price-source "c" 'weighted-average)
+     options gnc:pagename-general optname-price-source "c" 'average-cost)
 
     ;;(gnc:register-option
     ;; options

Modified: gnucash/trunk/src/report/standard-reports/equity-statement.scm
===================================================================
--- gnucash/trunk/src/report/standard-reports/equity-statement.scm	2008-07-16 15:39:17 UTC (rev 17340)
+++ gnucash/trunk/src/report/standard-reports/equity-statement.scm	2008-07-16 15:55:50 UTC (rev 17341)
@@ -144,7 +144,7 @@
     
     (gnc:options-add-price-source! 
      options pagename-commodities
-     optname-price-source "b" 'weighted-average)
+     optname-price-source "b" 'average-cost)
     
     (add-option 
      (gnc:make-simple-boolean-option

Modified: gnucash/trunk/src/report/standard-reports/income-statement.scm
===================================================================
--- gnucash/trunk/src/report/standard-reports/income-statement.scm	2008-07-16 15:39:17 UTC (rev 17340)
+++ gnucash/trunk/src/report/standard-reports/income-statement.scm	2008-07-16 15:55:50 UTC (rev 17341)
@@ -181,7 +181,7 @@
     
     (gnc:options-add-price-source! 
      options pagename-commodities
-     optname-price-source "b" 'weighted-average)
+     optname-price-source "b" 'average-cost)
     
     (add-option 
      (gnc:make-simple-boolean-option



More information about the gnucash-changes mailing list
--- gnucash/trunk/src/report/standard-reports/account-piecharts.scm	2008-07-16 15:39:17 UTC (rev 17340)
+++ gnucash/trunk/src/report/standard-reports/account-piecharts.scm	2008-07-16 15:55:50 UTC (rev 17341)
@@ -100,7 +100,7 @@
     
     (gnc:options-add-price-source! 
      options gnc:pagename-general
-     optname-price-source "c" 'weighted-average)
+     optname-price-source "c" 'average-cost)
 
     (add-option
      (gnc:make-account-list-option
@@ -238,8 +238,8 @@
         ;; Future improvement: Let the user choose which kind of
         ;; currency combining she want to be done. Right now
         ;; everything foreign gets converted
         ;; (gnc:sum-collector-commodity) based on the weighted
         ;; average of all past transactions.
         (gnc-numeric-to-double
          (gnc:gnc-monetary-amount
           (gnc:sum-collector-commodity 
@@ -238,8 +238,8 @@
         ;; currency combining she want to be done. Right now
         ;; everything foreign gets converted
-        ;; (gnc:sum-collector-commodity) based on the weighted
-        ;; average of all past transactions.
+        ;; (gnc:sum-collector-commodity) based on the average
+        ;; cost of all holdings.
         (gnc-numeric-to-double
          (gnc:gnc-monetary-amount

Modified: gnucash/trunk/src/report/standard-reports/account-summary.scm
===================================================================